
#include <windows.h>

#include "wrect.h"
#include "cl_dll.h"
#include "../engine/cdll_int.h"

#include "VGUI.h"
#include "VGUI_App.h"
#include "VGUI_Label.h"
#include "VGUI_Panel.h"
#include "VGUI_BorderLayout.h"

#define DLLEXPORT __declspec( dllexport )

cl_enginefunc_t gEngfuncs;

void VGui_Startup(void);
void VGui_Shutdown(void);


// Required DLL entry point
BOOL WINAPI DllMain( HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved)
{
   if (fdwReason == DLL_PROCESS_ATTACH)
   {
   }
   else if (fdwReason == DLL_PROCESS_DETACH)
   {
      VGui_Shutdown();  // free the allocated memory
   }

   return TRUE;
}


extern "C" 
{
int DLLEXPORT InitDisplay(cl_enginefunc_t *pEnginefuncs, int iVersion );
}


int DLLEXPORT InitDisplay( cl_enginefunc_t *pEnginefuncs, int iVersion )
{
	if (iVersion != CLDLL_INTERFACE_VERSION)
		return 0;

	memcpy(&gEngfuncs, pEnginefuncs, sizeof(cl_enginefunc_t));

	VGui_Startup();

   return 1;
}


using namespace vgui;


class NoVGUI_Viewport : public Panel
{
public:
	NoVGUI_Viewport(int x,int y,int wide,int tall);
	virtual void paintBackground();

	void *operator new( size_t stAllocateBlock );

};


NoVGUI_Viewport *gViewPort = NULL;


void VGui_Startup(void)
{
	Panel* root=(Panel*)gEngfuncs.VGui_GetPanel();
	root->setBgColor(128,128,0,0);
	root->setLayout(new BorderLayout(0));

   gViewPort = new NoVGUI_Viewport(0,0,root->getWide(),root->getTall());
   gViewPort->setParent(root);
}


void VGui_Shutdown(void)
{
   if (gViewPort)
      delete gViewPort;
}


NoVGUI_Viewport::NoVGUI_Viewport(int x,int y,int wide,int tall) : Panel(x,y,wide,tall)
{
	App::getInstance()->setCursorOveride( App::getInstance()->getScheme()->getCursor(Scheme::scu_none) );
}


//-----------------------------------------------------------------------------
// Purpose: Makes sure the memory allocated for NoVGUI_Viewport is nulled out
// Input  : stAllocateBlock - 
// Output : void *
//-----------------------------------------------------------------------------
void *NoVGUI_Viewport::operator new( size_t stAllocateBlock )
{
	void *mem = ::operator new( stAllocateBlock );
	memset( mem, 0, stAllocateBlock );
	return mem;
}


void NoVGUI_Viewport::paintBackground()
{
	int extents[4];
	getAbsExtents(extents[0],extents[1],extents[2],extents[3]);
	gEngfuncs.VGui_ViewportPaintBackground(extents);
}
